pub enum ConflictKeys {
NotRequested,
Available(Vec<ConflictingKeyRange>),
ReadFailed(FdbError),
}Expand description
The conflicting key ranges of a transaction attempt.
They are only read after a commit conflict, and only carry ranges when
TransactionOption::ReportConflictingKeys
was set on the transaction.
Variants
NotRequested
The attempt did not fail on a commit conflict, so nothing was read.
Available(Vec<ConflictingKeyRange>)
The special keyspace was read. The list is empty when
ReportConflictingKeys was not enabled.
ReadFailed(FdbError)
The special keyspace read failed.
Implementations
Sourceimpl ConflictKeys
impl ConflictKeys
Sourcepub fn ranges(&self) -> &[ConflictingKeyRange]
pub fn ranges(&self) -> &[ConflictingKeyRange]
The conflicting ranges, empty unless they were read successfully.